summaryrefslogtreecommitdiffstats
path: root/kmail/folderrequester.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderrequester.cpp')
-rw-r--r--kmail/folderrequester.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/folderrequester.cpp b/kmail/folderrequester.cpp
index 2be44c5a..06374664 100644
--- a/kmail/folderrequester.cpp
+++ b/kmail/folderrequester.cpp
@@ -16,11 +16,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
* Qt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -41,8 +41,8 @@
namespace KMail {
-FolderRequester::FolderRequester( TQWidget *parent, KMFolderTree *tree )
- : TQWidget( parent ), mFolder( 0 ), mFolderTree( tree ),
+FolderRequester::FolderRequester( TQWidget *tqparent, KMFolderTree *tree )
+ : TQWidget( tqparent ), mFolder( 0 ), mFolderTree( tree ),
mMustBeReadWrite( true ), mShowOutbox( true ), mShowImapFolders( true )
{
TQHBoxLayout * hlay = new TQHBoxLayout( this, 0, KDialog::spacingHint() );
@@ -116,7 +116,7 @@ void FolderRequester::setFolder( const TQString &idString )
//-----------------------------------------------------------------------------
void FolderRequester::keyPressEvent( TQKeyEvent * e )
{
- if ( e->key() == Qt::Key_Space )
+ if ( e->key() == TQt::Key_Space )
slotOpenDialog();
else
e->ignore();
@@ -16,11 +16,11 @@
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from